<?php
/* Copyright (C) 2007-2015 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2019      Open-DSI             <support@open-dsi.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *        \file       htdocs/sirene/admin/setup.php
 *        \ingroup    sirene
 *        \brief      Page to setup sirene module
 */

// Change this following line to use the correct relative path (../, ../../, etc)
$res = 0;
if (!$res && file_exists("../../main.inc.php")) $res = @require '../../main.inc.php';           // to work if your module directory is into a subdir of root htdocs directory
if (!$res && file_exists("../../../main.inc.php")) $res = @require '../../../main.inc.php';     // to work if your module directory is into a subdir of root htdocs directory
if (!$res) die("Include of main fails");
require_once DOL_DOCUMENT_ROOT . '/core/lib/admin.lib.php';
dol_include_once('/sirene/lib/sirene.lib.php');

$langs->load("admin");
$langs->load("sirene@sirene");
$langs->load("opendsi@sirene");

if (!$user->admin) accessforbidden();

$action = GETPOST('action', 'aZ09');


/*
 *	Actions
 */

$errors = [];
$error = 0;

if (preg_match('/set_(.*)/', $action, $reg)) {
    $code = $reg[1];
    $value = (GETPOST($code) ? GETPOST($code) : 1);
    $res = dolibarr_set_const($db, $code, $value, 'chaine', 0, '', $conf->entity);
    if (!($res > 0)) {
        $errors[] = $db->lasterror();
        $error++;
    }
} elseif (preg_match('/del_(.*)/', $action, $reg)) {
    $code = $reg[1];
    $res = dolibarr_del_const($db, $code, $conf->entity);
    if (!($res > 0)) {
        $errors[] = $db->lasterror();
        $error++;
    }
}

if ($action != '') {
    if (!$error) {
        setEventMessage($langs->trans("SetupSaved"));
        //        Header("Location: " . $_SERVER["PHP_SELF"]);
        //        exit;
    } else {
        setEventMessages('', $errors, 'errors');
    }
}

/*
 *  View
 */

$form = new Form($db);

llxHeader();

$linkback = '<a href="' . DOL_URL_ROOT . '/admin/modules.php">' . $langs->trans("BackToModuleList") . '</a>';
print load_fiche_titre($langs->trans("SireneSetup"), $linkback, 'title_setup');
print "<br>\n";

$head = sirene_admin_prepare_head();

print dol_get_fiche_head($head, 'settings_cron', $langs->trans("Module163027Name"), 0, 'opendsi@sirene');

print '<br>';

/********************************************************
 *  Sirene options
 ********************************************************/
print load_fiche_titre($langs->trans("SireneSireneCronOptions"), '', '');
print load_fiche_titre($langs->trans("SireneSireneCronOptionsDesc"), '', '');

print '<form method="POST" action="' . $_SERVER["PHP_SELF"] . '">';
print '<input type="hidden" name="token" value="' . newToken() . '" />';
print '<input type="hidden" name="action" value="set_sirene_cron_options">';

print '<div class="div-table-responsive-no-min">';
print '<table class="noborder centpercent">';

// SIRENE_CRON_COMPANY_NAME
print '<tr class="oddeven">' . "\n";
print '<td width="80%">' . $langs->trans("SireneCompanyName") . '</td>';
print '<td>' . "\n";
if (!empty($conf->use_javascript_ajax)) {
    print ajax_constantonoff('SIRENE_CRON_COMPANY_NAME', '', $conf->entity);
} else {
    if (empty($conf->global->SIRENE_CRON_COMPANY_NAME)) {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_SIRENE_CRON_COMPANY_NAME">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
    } else {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_SIRENE_CRON_COMPANY_NAME">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
    }
}
print '</td></tr>' . "\n";

// SIRENE_CRON_COMPANY_NAME_ALIAS
print '<tr class="oddeven">' . "\n";
print '<td width="80%">' . $langs->trans("SireneCompanyNameAlias") . '</td>';
print '<td>' . "\n";
if (!empty($conf->use_javascript_ajax)) {
    print ajax_constantonoff('SIRENE_CRON_COMPANY_NAME_ALIAS', '', $conf->entity);
} else {
    if (empty($conf->global->SIRENE_CRON_COMPANY_NAME_ALIAS)) {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_SIRENE_CRON_COMPANY_NAME_ALIAS">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
    } else {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_SIRENE_CRON_COMPANY_NAME_ALIAS">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
    }
}
print '</td></tr>' . "\n";

// SIRENE_CRON_ADRESS
print '<tr class="oddeven">' . "\n";
print '<td width="80%">' . $langs->trans("Address") . '</td>';
print '<td>' . "\n";
if (!empty($conf->use_javascript_ajax)) {
    print ajax_constantonoff('SIRENE_CRON_ADRESS', '', $conf->entity);
} else {
    if (empty($conf->global->SIRENE_CRON_ADRESS)) {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_SIRENE_CRON_ADRESS">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
    } else {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_SIRENE_CRON_ADRESS">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
    }
}
print '</td></tr>' . "\n";

// SIRENE_CRON_COMPANY_ZIP
print '<tr class="oddeven">' . "\n";
print '<td width="80%">' . $langs->trans("CompanyZip") . '</td>';
print '<td>' . "\n";
if (!empty($conf->use_javascript_ajax)) {
    print ajax_constantonoff('SIRENE_CRON_COMPANY_ZIP', '', $conf->entity);
} else {
    if (empty($conf->global->SIRENE_CRON_COMPANY_ZIP)) {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_SIRENE_CRON_COMPANY_ZIP">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
    } else {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_SIRENE_CRON_COMPANY_ZIP">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
    }
}
print '</td></tr>' . "\n";

// SIRENE_CRON_STATE_CODE
print '<tr class="oddeven">' . "\n";
print '<td width="80%">' . $langs->trans("StateShort") . '</td>';
print '<td>' . "\n";
if (!empty($conf->use_javascript_ajax)) {
    print ajax_constantonoff('SIRENE_CRON_STATE_CODE', '', $conf->entity);
} else {
    if (empty($conf->global->SIRENE_CRON_STATE_CODE)) {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_SIRENE_CRON_STATE_CODE">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
    } else {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_SIRENE_CRON_STATE_CODE">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
    }
}
print '</td></tr>' . "\n";

// SIRENE_CRON_CITY
print '<tr class="oddeven">' . "\n";
print '<td width="80%">' . $langs->trans("SireneTown") . '</td>';
print '<td>' . "\n";
if (!empty($conf->use_javascript_ajax)) {
    print ajax_constantonoff('SIRENE_CRON_CITY', '', $conf->entity);
} else {
    if (empty($conf->global->SIRENE_CRON_CITY)) {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_SIRENE_CRON_CITY">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
    } else {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_SIRENE_CRON_CITY">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
    }
}
print '</td></tr>' . "\n";

// SIRENE_CRON_RNA
print '<tr class="oddeven">' . "\n";
print '<td width="80%">' . $langs->trans("SireneRna") . '</td>';
print '<td>' . "\n";
if (!empty($conf->use_javascript_ajax)) {
    print ajax_constantonoff('SIRENE_CRON_RNA', '', $conf->entity);
} else {
    if (empty($conf->global->SIRENE_CRON_RNA)) {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_SIRENE_CRON_RNA">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
    } else {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_SIRENE_CRON_RNA">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
    }
}
print '</td></tr>' . "\n";

// SIRENE_CRON_NAF
print '<tr class="oddeven">' . "\n";
print '<td width="80%">' . $langs->trans("SireneNaf") . '</td>';
print '<td>' . "\n";
if (!empty($conf->use_javascript_ajax)) {
    print ajax_constantonoff('SIRENE_CRON_NAF', '', $conf->entity);
} else {
    if (empty($conf->global->SIRENE_CRON_NAF)) {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_SIRENE_CRON_NAF">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
    } else {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_SIRENE_CRON_NAF">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
    }
}
print '</td></tr>' . "\n";

// SIRENE_CRON_TVA
print '<tr class="oddeven">' . "\n";
print '<td width="80%">' . $langs->trans("SireneTvaIntra") . '</td>';
print '<td>' . "\n";
if (!empty($conf->use_javascript_ajax)) {
    print ajax_constantonoff('SIRENE_CRON_TVA', '', $conf->entity);
} else {
    if (empty($conf->global->SIRENE_CRON_TVA)) {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_SIRENE_CRON_TVA">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
    } else {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_SIRENE_CRON_TVA">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
    }
}
print '</td></tr>' . "\n";

// SIRENE_CRON_COUNTRY
print '<tr class="oddeven">' . "\n";
print '<td width="80%">' . $langs->trans("SireneCountry") . '</td>';
print '<td>' . "\n";
if (!empty($conf->use_javascript_ajax)) {
    print ajax_constantonoff('SIRENE_CRON_COUNTRY', '', $conf->entity);
} else {
    if (empty($conf->global->SIRENE_CRON_COUNTRY)) {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_SIRENE_CRON_COUNTRY">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
    } else {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_SIRENE_CRON_COUNTRY">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
    }
}
print '</td></tr>' . "\n";

// SIRENE_CRON_STAFF
print '<tr class="oddeven">' . "\n";
print '<td width="80%">' . $langs->trans("DictionaryStaff") . '</td>';
print '<td>' . "\n";
if (!empty($conf->use_javascript_ajax)) {
    print ajax_constantonoff('SIRENE_CRON_STAFF', '', $conf->entity);
} else {
    if (empty($conf->global->SIRENE_CRON_STAFF)) {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_SIRENE_CRON_STAFF">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
    } else {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_SIRENE_CRON_STAFF">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
    }
}
print '</td></tr>' . "\n";

// SIRENE_CRON_JURI_STATUS
print '<tr class="oddeven">' . "\n";
print '<td width="80%">' . $langs->trans("SireneJuridicalStatusLevel2") . '</td>';
print '<td>' . "\n";
if (!empty($conf->use_javascript_ajax)) {
    print ajax_constantonoff('SIRENE_CRON_JURI_STATUS', '', $conf->entity);
} else {
    if (empty($conf->global->SIRENE_CRON_JURI_STATUS)) {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_SIRENE_CRON_JURI_STATUS">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
    } else {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_SIRENE_CRON_JURI_STATUS">' . img_picto($langs->trans("Enabled"), 'switch_on') . '</a>';
    }
}
print '</td></tr>' . "\n";

print '</table>';
print '</div>';

print '</form>';


print dol_get_fiche_end();

llxFooter();

$db->close();
