<?php
/* Copyright (C) 2019      Open-DSI             <support@open-dsi.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *      \file       htdocs/sirene/class/actions_sirene.class.php
 *      \ingroup    sirene
 *      \brief
 */


dol_include_once('/sirene/class/sirene.class.php');


/**
 * Action Class for Dolibarr Hook
 */
class ActionsSirene
{
    /**
     * @var DoliDB Database handler.
     */
    public $db;
    /**
     * @var string Error
     */
    public $error = '';
    /**
     * @var array Errors
     */
    public $errors = array();

    /**
     * @var array Hook results. Propagated to $hookmanager->resArray for later reuse
     */
    public $results = array();

    /**
     * @var string String displayed by executeHook() immediately after return
     */
    public $resprints;

    /**
     * Constructor
     *
     * @param DoliDB $db Database handler
     */
    public function __construct($db)
    {
        $this->db = $db;
    }

    /**
     * Overloading the doActions function : replacing the parent's function with the one below
     *
     * @param       array()         $parameters     Hook metadatas (context, etc...)
     * @param       CommonObject    $object         The object to process (an invoice if you are in invoice module, a propale in propale's module, etc...)
     * @param       string          $action         Current action (if set). Generally create or edit or null
     * @param       HookManager     $hookmanager    Hook manager propagated to allow calling another hook
     * @return      int                             < 0 on error, 0 on success, 1 to replace standard code
     */
    public function doActions($parameters, &$object, &$action, $hookmanager)
    {
        global $conf, $langs, $user;


        $context = explode(':', $parameters['context']);
        $confirm = GETPOST('confirm', 'alpha');
        if (in_array('thirdpartycard', $context)) {
            $langs->load('sirene@sirene');

            if ($action == 'add') {
                // set Sirene update date on create thirdparty only if company values set and provide from Sirene database
                // so we can check value of administrative status provide from Sirene
                $sirene_company_admin_status = GETPOST('options_sirene_company_admin_status', 'alpha');
                if (in_array($sirene_company_admin_status, array(Sirene::COMPANY_ADMIN_STATUS_OPENED, Sirene::COMPANY_ADMIN_STATUS_CLOSED))) {
                    $now = dol_now();
                    $now_arr = dol_getdate($now);
                    // set update date
                    $_POST['options_sirene_update_datehour'] = $now_arr['hours'];
                    $_POST['options_sirene_update_datemin'] = $now_arr['minutes'];
                    $_POST['options_sirene_update_datesec'] = $now_arr['seconds'];
                    $_POST['options_sirene_update_dateday'] = $now_arr['mday'];
                    $_POST['options_sirene_update_datemonth'] = $now_arr['mon'];
                    $_POST['options_sirene_update_dateyear'] = $now_arr['year'];
                }
            }

            if (GETPOST('sirene_search') != '') {
                $_SESSION['companies_results'] = array();
                $sirene = new Sirene($this->db);

                $company_name = GETPOST('sirene_company_name', 'alpha');
                $naf = GETPOST('sirene_naf', 'alpha');
                if ((!empty($naf)) && stristr($naf, '.') === false ) {
                    $naf = substr($naf, 0, 2) . '.' . substr($naf, 2, 3);
                }
                $naf = str_replace(' ', '', $naf);
                $rna = GETPOST('sirene_rna', 'alpha');
                $rna = str_replace(' ', '', $rna);
                $zipcode = GETPOST('sirene_zipcode', 'alpha');
                $town = GETPOST('sirene_town', 'alpha');
                $siren_siret = GETPOST('siren_siret', 'alpha');
                $siren_siret = str_replace(' ', '', $siren_siret);

                // Recuperation number
                $number = GETPOST('sirene_number', 'int');
                $only_open = GETPOST('sirene_only_open', 'int');
                $only_company_siege = GETPOST('sirene_only_open_siege', 'int');

                //Condition number
                $number = $number <= 0 ? 20 : ($number > 100 ? 100 : $number);

                $siret = '';
                $siren = '';

                // siren has 9 digits and siret has 14 digits
                if (count(str_split($siren_siret)) === 9) {
                    $siren = $siren_siret;
                } elseif (count(str_split($siren_siret)) === 14) {
                    $siret = $siren_siret;
                }

                $result = $sirene->connectionSireneApi();
                if ($result < 0) {
                    setEventMessages($langs->trans('SireneErrorWhileConnect'), $sirene->errors, 'errors');
                    $this->error = $sirene->error;
                    $this->errors = $sirene->errors;
                    return -1;
                }

                $result = $sirene->searchCompanies($company_name, $siren, $siret, $rna, $naf, $zipcode, $number, $town, $only_open, $only_company_siege);

                // if there is no results with Sirene API: search with the RNA api if there is a RNA number
                if (empty($sirene->companies_results) && $rna) {
                    $result = $sirene->connectionRnaAPi();
                    $result = $sirene->searchCompanyByRna($rna);
                }

                if ($result < 0) {
                    setEventMessages($langs->trans('SireneErrorWhileGetCompanies'), $sirene->errors, 'errors');
                } elseif (empty($sirene->companies_results)) {
                    setEventMessage($langs->trans('SireneCompaniesNotFound'), 'warnings');
                } else {
                    $_GET['sirene_action'] = 'sirene_set';
                }

                if ($action == 'add') {
                    $action = 'create';
                } else {
                    $action = 'edit';
                }
            } elseif ($action == 'confirm_sirene_set') {
                if (!empty($_SESSION['sirene_save_post'])) {
                    foreach ($_SESSION['sirene_save_post'] as $key => $value) {
                        $_POST[$key] = $value;
                    }
                    $_SESSION['sirene_save_post'] = array();
                }

                $confirm = GETPOST('confirm', 'alpha');

                if ($confirm == 'yes') {
                    // retrieve the selected company data from unique siret or its rna
                    $siret = GETPOST('sirene_choice', 'alpha');
                    if (isset($_SESSION['companies_results'])) {
                        foreach ($_SESSION['companies_results'] as $company) {
                            if ($company['siret'] == $siret || $company['rna'] == $siret) {
                                $company_infos = $company;
                            }
                        }
                        unset($_SESSION['companies_results']);

                        if ($company_infos['siren']) {
                            $vatIntraNUmber = $this->calculateIntraCommunityVat($company_infos['siren']);
                            $company_infos['tva_intra'] = 'FR' . str_pad($vatIntraNUmber, 2, 0, STR_PAD_LEFT) . $company_infos['siren'];
                        } else {
                            $company_infos['tva_intra'] = '';
                        }

                        $company_infos['country'] = GETPOST('country', 'int') . $company_infos['siren'];
                        $_GET['civility_id'] = $company_infos['civility'];
                        $_GET['name'] = $company_infos['company_name'];
                        $_GET['name_alias'] = $company_infos['company_name_alias'];
                        $_GET['firstname'] = $company_infos['firstname'];
                        $_GET['private'] = $company_infos['private'];
                        $_GET['address'] = $company_infos['address'];
                        $_GET['zipcode'] = $company_infos['zipcode'];
                        $_GET['country_id'] = $company_infos['country_id'];
                        $_GET['town'] = $company_infos['town'];
                        $_GET['state_id'] = $company_infos['state_id'];
                        $_GET['idprof1'] = $company_infos['siren'];
                        $_GET['idprof2'] = $company_infos['siret'];
                        $_GET['idprof3'] = $company_infos['codenaf_san'];
                        $_GET['idprof6'] = $company_infos['rna'];
                        $_GET['tva_intra'] = $company_infos['tva_intra'];
                        $_GET['country'] = $company_infos['country'];
                        $_GET['country_code'] = $company_infos['country_code'];
                        $_GET['country_san'] = $company_infos['country_san'];
                        $_GET['effectif_id'] = $company_infos['staff'];  // effectif
                        $_GET['forme_juridique_code'] = $company_infos['legalcategory'];  // type d'entité légale niveau 2
                        // company administrative status
                        $_POST['options_sirene_company_admin_status'] = $company_infos['status']; // post priority in extra field
                        $_GET['options_sirene_company_admin_status'] = $company_infos['status']; // then get (to be sure)	 */

                        $_GET['latitude'] = $company_infos['latitude'];
                        $_GET['longitude'] = $company_infos['longitude'];
                    }
                }
                $old_action = GETPOST('old_action', 'alpha');
                if ($old_action == 'create') {
                    $action = 'create';
                } else {
                    $action = 'edit';
                }

            } elseif ($action == 'confirm_sir_data' && $confirm == 'yes' && $user->rights->societe->creer) {
                // retrieve the company result from the session
                $company_infos = $_SESSION['companies_results'][0];

                $correspondanceArray = $this->getCorrespondanceArrayBetweenCompanyInfoAndSocieteObj();

                $object->oldcopy = clone $object;
                $modified = false;

                foreach ($correspondanceArray as $key => $property_name) {
                    if ($key == 'country_id') {
                        // no checkbox for country id (it's a hidden input)
                        // get the choice to update country id from country checkbox
                        $choice_key = 'choice_country';
                    } else {
                        $choice_key = 'choice_'.$key;
                    }
                    $choice = GETPOST($choice_key, 'int');
                    if (!empty($choice)) {
                        $object->$property_name = $company_infos[$key];
                        $modified = true;
                    }
                }

                // company administrative status
                $company_admin_status = isset($object->array_options['options_sirene_company_admin_status']) ? $object->array_options['options_sirene_company_admin_status'] : '';
                if (isset($company_infos['status']) && $company_infos['status'] != '' && $company_admin_status != $company_infos['status']) {
                    $object->array_options['options_sirene_company_admin_status'] = $company_infos['status'];
                    $modified = true;
                }

                $object->array_options['options_sirene_status'] = 0;
                $object->array_options['options_sirene_update_date'] = dol_now();

                if ($this->updateObjectFields($modified, $object, $user) === -1) {
                    return -1;
                }

            } elseif ($action == 'confirm_sirene_update' && $confirm == 'yes' && $user->rights->societe->creer) {
                $correspondanceArray = $this->getCorrespondanceArrayBetweenCompanyInfoAndSocieteObj();
                $object->oldcopy = clone $object;
                $modified = false;

                foreach ($correspondanceArray as $key => $property_name) {
                    $choice = GETPOST('choice_' . $key, 'int');
                    if (!empty($choice)) {
                        $company_info = GETPOST($key, 'alpha');
                        $object->$property_name = $company_info;
                        $modified = true;
                    }
                }

                $object->array_options['options_sirene_status'] = 0;
                $object->array_options['options_sirene_update_date'] = dol_now();
                $object->array_options['options_sirene_company_admin_status'] = 'A';

                if ($this->updateObjectFields($modified, $object, $user) === -1) {
                    return -1;
                }
            }
        }
        return 0;
    }


    /**
     * Overloading the formObjectOptions function : replacing the parent's function with the one below
     *
     * @param array() $parameters Hook metadatas (context, etc...)
     * @param CommonObject $object The object to process (an invoice if you are in invoice module, a propale in propale's module, etc...)
     * @param string $action Current action (if set). Generally create or edit or null
     * @param HookManager $hookmanager Hook manager propagated to allow calling another hook
     * @return  int                             < 0 on error, 0 on success, 1 to replace standard code
     */
    public function formObjectOptions($parameters, &$object, &$action, $hookmanager)
    {
        global $conf, $langs, $form, $user, $mysoc;
        $context = explode(':', $parameters['context']);

        if (in_array('thirdpartycard', $context)) {
            if ($action != 'create' && $action != 'edit') {
                if (strtoupper($object->country_code) == 'FR') {

                    $codenaf = trim(strtoupper($object->idprof3));
                    if (isset($codenaf) && !empty($codenaf)) {
                        $langs->load('sirene@sirene');

                        $sql = "SELECT label FROM " . MAIN_DB_PREFIX . "c_codenaf WHERE code = '" . $this->db->escape($codenaf) . "'";
                        $result = $this->db->query($sql);
                        if ($result) {
                            if ($this->db->num_rows($result) == 1) {
                                $obj = $this->db->fetch_object($result);
                                $codenaf = $codenaf . ' - ' . $langs->trans($obj->label);
                            } else {
                                $codenaf = '<span style="color:red">' . $codenaf . ' - ' . $langs->trans('SireneErrorCodeNafNotFound', dol_buildpath('/admin/dict.php', 1)/*.'?id='.$dict_id*/) . '</span>';
                            }

                            $idprof3 = $langs->transcountry('ProfId3', $object->country_code);
                            print "\n" . '<script type="text/javascript" language="javascript">';
                            print '$(document).ready(function () {
                            $("div.fichehalfleft td:contains(\'' . str_replace('\'', '\\\'', $idprof3) . '\')").next().html(\'' . str_replace('\'', '\\\'', $codenaf) . '\');
                        })';
                            print '</script>' . "\n";
                        }
                    }
                }

            } elseif ($action == 'create' || $action == '') {

                $sirene_action = GETPOST('sirene_action', 'alpha');
                $required_inputs = array();

                // required inputs for url societe/card.php?action=create
                if (isset($user->default_values['societe/card.php']['mandatory']['action=create'])) {
                    foreach ($user->default_values['societe/card.php']['mandatory']['action=create'] as $input_name => $val) {
                        if (! in_array($input_name, $required_inputs)) {
                            $required_inputs[] = $input_name;
                        }
                    }
                }

                // required inputs for url societe/card.php
                if (isset($user->default_values['societe/card.php']['mandatory']['_noquery_'])) {
                    foreach ($user->default_values['societe/card.php']['mandatory']['_noquery_'] as $input_name => $val) {
                        if (! in_array($input_name, $required_inputs)) {
                            $required_inputs[] = $input_name;
                        }
                    }
                }
                // put back 'required' for mandotory fields
                print '<script type="text/javascript">
                $(document).ready(function () {';

                    foreach ($required_inputs as $input_name ) {
                        print 'jQuery("select[name=\'' . $input_name . '\']").prop(\'required\',true);' . "\n";
                        print 'jQuery("input[name=\'' . $input_name . '\']").prop(\'required\',true);' . "\n";
                        // replace -1 or 0 by ''
                        print 'jQuery("select[name=\'' . $input_name . '\'] option[value=\'-1\']").prop(\'value\', \'\');' . "\n";
                        print 'jQuery("select[name=\'' . $input_name . '\'] option[value=\'0\']").prop(\'value\', \'\');' . "\n";
                        print 'jQuery("textarea[name=\'' . $input_name . '\']").prop(\'required\',true);' . "\n";
                    }
                print '});
                </script>';

                $this->display_sirene_form();

                // remove 'required' from mandatory fieds when sirene form submited
                print '
                        <script type="text/javascript">
                            $(document).ready(function () {
                            $("#sirene_search_btn").click(function() {';
                                foreach ($required_inputs as $input_name) {
                                    print 'jQuery("select[name=\'' . $input_name . '\']").prop(\'required\',false);' . "\n";
                                    print 'jQuery("input[name=\'' . $input_name . '\']").prop(\'required\',false);' . "\n";
                                    print 'jQuery("textarea[name=\'' . $input_name . '\']").prop(\'required\',false);' . "\n";
                                }
                print ' });
                        }); </script>';

                // display companies results
                if ($sirene_action == 'sirene_set') {
                    $table_choices = '<table id="sirene_table" class="noborder centpercent">' . "\n";
                    $table_choices .= '<tr class="liste_titre">' . "\n";
                    $table_choices .= '<td width="20px"></td>' . "\n";
                    $table_choices .= '<td>' . $langs->trans("SireneCompanyName") . '</td>' . "\n";
                    $table_choices .= '<td>' . $langs->trans("Address") . '</td>' . "\n";
                    $table_choices .= '<td>' . $langs->trans("SireneCreateDate") . '</td>' . "\n";
                    $table_choices .= '<td>' . $langs->trans("SireneCloseDate") . '</td>' . "\n";
                    $table_choices .= '<td>' . $langs->trans("SireneNaf") . '</td>' . "\n";
                    $table_choices .= '<td>' . $langs->trans("SireneSiren") . '</td>' . "\n";
                    $table_choices .= '<td>' . $langs->trans("SireneSiret") . '</td>' . "\n";
                    $table_choices .= '<td> RNA </td>' . "\n";
                    $table_choices .= '</tr>' . "\n";

                    $checked = true;

                    foreach ($_SESSION['companies_results'] as $companny_infos) {
                        if ($companny_infos['status'] == Sirene::COMPANY_ADMIN_STATUS_OPENED and $checked) {
                            $table_choices .= $this->makeTableRowCompany($companny_infos, $checked);
                            $checked = false;
                        } else {
                            $table_choices .= $this->makeTableRowCompany($companny_infos, $checked);
                        }
                    }

                    $table_choices .= '</table>' . "\n";
                    $_SESSION['sirene_save_post'] = array();
                    $properties_bypassed = array('token', 'sirene_search', 'action');

                    foreach ($_POST as $key => $value) {
                        if (in_array($key, $properties_bypassed)) continue;
                        $_SESSION['sirene_save_post'][$key] = $value;
                    }

                    $formquestion = array(
                        array(
                            'type'  => 'hidden',
                            'name'  => 'old_action',
                            'value' => $action
                        ),
                        array(
                            'name'  => 'sirene_choice',
                            'type'  => 'onecolumn',
                            'value' => $table_choices
                        )
                    );

                    print $form->formconfirm($_SERVER["PHP_SELF"], $langs->trans("PopUpSelectionTier"), $langs->trans("PopUpSelectionTierMsg"), "confirm_sirene_set", $formquestion, 'no', 1, 400, '75%');
                }
                print '<br>' . "\n";
                print '</div>' . "\n";
                print
                    <<<SCRIPT
    <script type="text/javascript">
        $(document).ready(function () {
            var sirene_tr = $("tr#sirene_infos");
            var sirene_block = $("div#sirene_block_infos");
            var sirene_anchor = sirene_tr.closest('table');

            sirene_block.detach().insertBefore(sirene_anchor);
            sirene_tr.remove();

            $('table#sirene_table tr').click(function(event) {
                if (event.target.type !== 'radio') {
                    $(':radio', this).trigger('click');
                }
            });
        });
    </script>
SCRIPT;
                print '</td></tr>' . "\n";
            }

            // if module addressefrance is not enabled and the addresse option of sirene is enabled
            if ($conf->global->SIRENE_ADDRESSES && !isset($conf->adressefrance)) {
                // search addresses frances api
                if ($action == 'create' or $action == 'edit') {
                    print '<script src="'.dol_buildpath('/sirene/js/search_addresses.js', 1).'"></script>';
                }

                // if the module prospecting map is not enabled, add the JS script to search for an adresse when the sirene result is confirm
                // prospecting map module does the same thing
                if (! isset($conf->prospectingmap)) {
                    if ($action == 'create' or $action == 'edit') {
                        //print '<script src="'.dol_buildpath('/sirene/js/search_addresses_and_get_location.js', 1).'"></script>';
                    }
                }
            }

            if (GETPOST('latitude') && GETPOST('longitude')) {
                print "<script>
                const inputAddress = document.getElementById('address');

                const inputLatitude = document.createElement('input');
                inputLatitude.setAttribute('type', 'hidden');
                inputLatitude.setAttribute('id', 'latitude');
                inputLatitude.setAttribute('value', ".GETPOST('latitude').");
                inputAddress.after(inputLatitude);

                const inputLongitude = document.createElement('input');
                inputLongitude.setAttribute('type', 'hidden');
                inputLongitude.setAttribute('id', 'longitude');
                inputLongitude.setAttribute('value', ".GETPOST('longitude').");
                inputAddress.after(inputLongitude);
                </script>";
            }
        }
        return 0;
    }

    /**
     * Overloading the getIdProfUrl function : replacing the parent's function with the one below
     *
     * @param array() $parameters Hook metadatas (context, etc...)
     * @param CommonObject $object The object to process (an invoice if you are in invoice module, a propale in propale's module, etc...)
     * @param string $action Current action (if set). Generally create or edit or null
     * @param HookManager $hookmanager Hook manager propagated to allow calling another hook
     * @return  int                             < 0 on error, 0 on success, 1 to replace standard code
     */
    public function getIdProfUrl($parameters, &$object, &$action, $hookmanager)
    {
        global $conf, $langs;

        $url = '';
        if (empty($conf->global->MAIN_DISABLEPROFIDRULES)) {
            $idprof = $parameters['idprof'];
            $thirdparty = $parameters['company'];

            // TODO Move links to validate professional ID into a dictionary table "country" + "link"
            $strippedIdProf1 = str_replace(' ', '', $thirdparty->idprof1);
            if ($idprof == 1 && $thirdparty->country_code == 'FR') {
                if (!empty($conf->global->SIRENE_VERIFICATION_SIRET_URL)) {
                    $url = $conf->global->SIRENE_VERIFICATION_SIRET_URL . $strippedIdProf1;
                } else {
                    $url = 'https://annuaire-entreprises.data.gouv.fr/entreprise/' . $strippedIdProf1;
                }
            }
            if ($idprof == 1 && ($thirdparty->country_code == 'GB' || $thirdparty->country_code == 'UK')) {
                $url = 'https://beta.companieshouse.gov.uk/company/' . $strippedIdProf1;
            }
            if ($idprof == 1 && $thirdparty->country_code == 'ES') {
                $url = 'https://www.e-informa.es/servlet/app/portal/ENTP/screen/SProducto/prod/ETIQUETA_EMPRESA/nif/' . $strippedIdProf1;
            }
            if ($idprof == 1 && $thirdparty->country_code == 'IN') {
                $url = 'http://www.tinxsys.com/TinxsysInternetWeb/dealerControllerServlet?tinNumber=' . $strippedIdProf1 . ';&searchBy=TIN&backPage=searchByTin_Inter.jsp';
            }
            if ($idprof == 1 && $thirdparty->country_code == 'PT') {
                $url = 'https://www.nif.pt/' . $strippedIdProf1;
            }

            if (!empty($url)) {
                $this->resprints = '<a target="_blank" href="' . $url . '">' . $langs->trans('Check') . ' ' . img_picto($langs->trans("SIRENIntraCheckDesc"), 'info') . '</a>';
                return 1;
            }
        }

        return 0;
    }

    /**
     * Overloading the addMoreActionsButtons function : replacing the parent's function with the one below
     *
     * @param array() $parameters Hook metadatas (context, etc...)
     * @param CommonObject $object The object to process (an invoice if you are in invoice module, a propale in propale's module, etc...)
     * @param string $action Current action (if set). Generally create or edit or null
     * @param HookManager $hookmanager Hook manager propagated to allow calling another hook
     * @return  int                             < 0 on error, 0 on success, 1 to replace standard code
     */
    public function addMoreActionsButtons($parameters, &$object, &$action, $hookmanager)
    {
        global $user, $langs, $form, $sirene, $conf;
        global $colorbackhmenu1;
        require_once DOL_DOCUMENT_ROOT . '/core/lib/admin.lib.php';
        $langs->loadLangs(array('sirene@sirene', 'companies'));
        //le contexte est utilisé comme indicateur de situations ou executer notre code -> utilisé dans les hooks
        $context = explode(':', $parameters['context']);

        //on se situe dans la fiche des tiers (thirdpartycard)
        if (in_array('thirdpartycard', $context)) {
            if ($user->rights->societe->creer) {
                //SI LE TIERS A UN SIRET ET ACTION N'EST PAS sir_update (POUR METTRE À JOUR UN TIERS AVEC SIRET FERMÉ)
                if (!empty($object->idprof2) && GETPOST('action') !== 'sir_update') {
                    //display SIREN btn to check company data with SIRENE API
                    print '<div class="inline-block divButAction"><a class="butAction" href="' . $_SERVER['PHP_SELF'] . '?socid=' . $object->id . '&amp;action=sir_data">' . $langs->trans('SireneButton') . '</a></div>';
                    $act = GETPOST('action', 'aZ09');

                    if ($act == 'sir_data') {
                        $sirene = new Sirene($this->db);
                        $result = $sirene->connectionSireneApi();
                        $result = $sirene->getOneCompanyBySiret($object->idprof2);

                        if ($result < 0) {
                            setEventMessages($langs->trans('SireneErrorWhileGetCompanies'), $sirene->errors, 'errors');
                            return -1;
                        } elseif (empty($sirene->companies_results)) {
                            setEventMessage($langs->trans('SireneCompaniesNotFound'), 'warnings');
                            return 0;
                        }

                        $formquestion = array();
                        $company_infos = $sirene->companies_results[0];
                        $v13p = version_compare(DOL_VERSION, '13.0.0', '>=');

                            $correspondance = array(
                                'company_name'         => array('title'    => $langs->trans("SireneCompanyName"),
                                                                'dolibarr' => $object->name,
                                                                'sirene'   => $company_infos['company_name'],
                                                                'sirene_show'   => $company_infos['company_name']),
                                'company_name_alias'   => array('title'    => $langs->trans("SireneCompanyNameAlias"),
                                                                'dolibarr' => $object->name_alias,
                                                                'sirene'   => $company_infos['company_name_alias'],
                                                                'sirene_show'   => $company_infos['company_name_alias']),
                                'address'              => array('title'    => $langs->trans("Address"),
                                                                'dolibarr' => $object->address,
                                                                'sirene'   => $company_infos['address'],
                                                                'sirene_show'   => $company_infos['address']),
                                'zipcode'              => array('title'    => $langs->trans("CompanyZip"),
                                                                'dolibarr' => $object->zip,
                                                                'sirene'   => $company_infos['zipcode'],
                                                                'sirene_show'   => $company_infos['zipcode']),
                                'state_id'             => array('title'    => $langs->trans("StateShort"),
                                                                'dolibarr' => $object->state_code,
                                                                'sirene'   		=> $company_infos['state_id'],
                                                                'sirene_show'   => $company_infos['state_san']),
                                'town'                 => array('title'    => $langs->trans("SireneTown"),
                                                                'dolibarr' => $object->town,
                                                                'sirene'   => $company_infos['town'],
                                                                'sirene_show'   => $company_infos['town']),
                                'siren'                => array('title'    => $langs->trans("SireneSiren"),
                                                                'dolibarr' => $object->idprof1,
                                                                'sirene'   => $company_infos['siren'],
                                                                'sirene_show'   => $company_infos['siren']),
                                'siret'                => array('title'    => $langs->trans("SireneSiret"),
                                                                'dolibarr' => $object->idprof2,
                                                                'sirene'   => $company_infos['siret'],
                                                                'sirene_show'   => $company_infos['siret']),
                                'rna'                => array('title'    => $langs->trans("SireneRna"),
                                                                        'dolibarr' => $object->idprof6,
                                                                        'sirene'   => $company_infos['rna'],
                                                        'sirene_show'   => $company_infos['rna']),
                                'codenaf_san'          => array('title'    => $langs->trans("SireneNaf"),
                                                                'dolibarr' => $object->idprof3,
                                                                'sirene'   => $company_infos['codenaf_san'],
                                                                'sirene_show'   => $company_infos['codenaf_san']),
                                'sirene_tva_intra'     => array('title'    => $langs->trans("SireneTvaIntra"),
                                                                'dolibarr' => $object->tva_intra,
                                                                'sirene'   => $company_infos['sirene_tva_intra'],
                                                                'sirene_show'   => $company_infos['sirene_tva_intra']),
                                'country'              => array('title'    => $langs->trans("SireneCountry"),
                                                                'dolibarr' => $object->country,
                                                                'sirene'   => $company_infos['country'],
                                                                'sirene_show'   => $company_infos['country']),
                                'country_id'           => array('title'    => $langs->trans("SireneCountryISO"),
                                                                'dolibarr' => $object->country_id,
                                                                'sirene'   => $company_infos['country_id'],
                                                                'sirene_show'   => $company_infos['country_id']),
                                'staff'          => array('title'    => $langs->trans("DictionaryStaff"),
                                                                'dolibarr' => $object->effectif,
                                                                'sirene'   => $company_infos['staff'],
                                                                'sirene_show'   => $company_infos['staff_label']),
                                //type d'entité légale
                                'legalcategory'     => array('title'    => $langs->trans("SireneJuridicalStatusLevel2"),
                                                                'dolibarr' => $object->forme_juridique,
                                                                'sirene'   => $company_infos['legalcategory'],
                                                                'sirene_show'   => $company_infos['legalcategory_id']),
                            );

                            if ($company_infos['status'] == Sirene::COMPANY_ADMIN_STATUS_CLOSED) {
                                $action = $_GET['action'] = $_POST['action'] = "sir_update";
                                $parameters['closed_thirdparty'] = true;
                                return $this->addMoreActionsButtons($parameters, $object, $action, $hookmanager);
                            }

                            $table_choices = '<div class="div-table-responsive">';
                            $table_choices .= '<table class="noborder centpercent">' . "\n";
                            $table_choices .= '<tr class="liste_titre">' . "\n";

                            $table_choices .= '<td><span class="liste_titre" style="font-size: 12px; font-size: large; title="' . $langs->trans("SireneFieldNameDesc") . '">' . $langs->trans("SireneFieldName") . '</span><td>' . "\n";
                            $table_choices .= '<td><span class="liste_titre" style="font-size: 12px; font-size: large;" title="' . $langs->trans("SireneDataDolibarrDesc") . '">' . $langs->trans("SireneDataDolibarr") . '</span><td>' . "\n";
                            $table_choices .= '<td><span class="fas fa-caret-left marginleftonlyshort valignmiddle"  style="font-size: 28px" title="' . $langs->trans("SireneInputUpdateDesc") . '"></span><td>' . "\n";
                            $table_choices .= '<td><input type="checkbox" id="checkallactions" value="1"><td>' . "\n";
                            $table_choices .= '<td><span class="liste_titre" style="font-size: 12px; font-size: large;" title="' . $langs->trans("SireneDataSireneDesc") . '">' . $langs->trans("SireneDataSirene") . '</span><td>' . "\n";
                            $table_choices .= '</tr>' . "\n";

                            require_once DOL_DOCUMENT_ROOT . '/core/lib/functions2.lib.php';
                            $path = '';        // This value may be used in future for external module to overwrite theme
                            $theme = 'eldy';    // Value of theme
                            if (!empty($conf->global->MAIN_OVERWRITE_THEME_RES)) {
                                $path = '/' . $conf->global->MAIN_OVERWRITE_THEME_RES;
                                $theme = $conf->global->MAIN_OVERWRITE_THEME_RES;
                            }

                            include dol_buildpath($path . '/theme/' . $theme . '/theme_vars.inc.php');
                            // Case of option availables only if THEME_ELDY_ENABLE_PERSONALIZED is on
                            $colorbackhmenu1 = empty($user->conf->THEME_ELDY_ENABLE_PERSONALIZED) ? (empty($conf->global->THEME_ELDY_TOPMENU_BACK1) ? $colorbackhmenu1 : $conf->global->THEME_ELDY_TOPMENU_BACK1) : (empty($user->conf->THEME_ELDY_TOPMENU_BACK1) ? $colorbackhmenu1 : $user->conf->THEME_ELDY_TOPMENU_BACK1);

                            // Set text color to black or white
                            $colorbackhmenu1 = join(',', colorStringToArray($colorbackhmenu1));    // Normalize value to 'x,y,z'
                            $tmppart = explode(',', $colorbackhmenu1);
                            $tmpval = (!empty($tmppart[0]) ? $tmppart[0] : 0) + (!empty($tmppart[1]) ? $tmppart[1] : 0) + (!empty($tmppart[2]) ? $tmppart[2] : 0);
                            if ($tmpval <= 460) $colortextbackhmenu = 'FFFFFF';
                            else $colortextbackhmenu = '000000';

                        $table_css = "
                        <style>
                            .sirene_color_title {
                                background-color: rgb($colorbackhmenu1) !important;
                                color: #$colortextbackhmenu !important;
                            }
                            .warning_text {
                                font-size:16px;
                                font-weight:bold
                            }
                        </style>";

                        $table_choices .= $table_css;
                        // script to check and uncheck all checkboxes
                        $path_table_js = dol_buildpath('/sirene/js/table_checkboxes.js', 1);
                        $table_choices .= '<script src='.$path_table_js.'></script>';

                        $more_names = '';

                            foreach ($correspondance as $key => $infos) {
                                if ($key == 'country_id') {
                                    $table_choices .= '<input type="hidden" id="' . $key . '" name="' . $key . '" value="' . $infos['sirene'] . '">';
                                } elseif ($key == 'company_name_alias'){
                                    // Peut peut-être être modifié, cette partie sert lorsque c'est une entité physique, de sorte que dans ce cas, la ligne 'nom alternatif' ne s'affiche pas
                                    // Avant elle s'affichait mais était vide, visuellement ce n'est pas beau
                                    $table_choices .= '<tr>';
                                    $table_choices .= '<td>' . $infos['title'] . '<td>';$table_choices .= '<td>' . $infos['dolibarr'] . '<td>';
                                    //  $table_choices .= '<td>' . @$infos['<-'] . '<td>';//select all checkbox
                                    $table_choices .= '<td><td>';//select all checkbox
                                    $table_choices .= '<td><input type="checkbox" id="choice_' . $key . '" name="choice_' . $key . '" class="checkforselect" value="1" ' . (trim($infos['dolibarr']) == trim($infos['sirene_show']) ? 'disabled="disabled"' : '') . '><td>';
                                    $table_choices .= '<td>' . $infos['sirene_show'] . '<td>';$table_choices .= '</tr>' . "\n";
                                    $table_choices .= '</tr>' . "\n";
                                } else {
                                    $table_choices .= '<tr>';
                                    $table_choices .= '<td>' . $infos['title'] . '<td>';
                                    $table_choices .= '<td>' . $infos['dolibarr'] . '<td>';
                                    //$table_choices .= '<td>' . @$infos['<-'] . '<td>';
                                    $table_choices .= '<td><td>';
                                    //select all checkbox
                                    $table_choices .= '<td><input type="checkbox" id="choice_' . $key . '" name="choice_' . $key . '" class="checkforselect" value="1" ' . (trim($infos['dolibarr']) == trim($infos['sirene_show']) ? 'disabled="disabled"' : '') . '><td>';
                                    $table_choices .= '<td>' . $infos['sirene_show'] . '<td>';
                                    $table_choices .= '</tr>' . "\n";
                                }
                                if ($v13p) {
                                    $more_names .= ',choice_' . $key;
                                } else {
                                    $formquestion[] = array('name' => 'choice_'.$key);
                                }
                            }
                            $table_choices .= '</table>' . "\n";
                            $table_choices .= '</div>' . "\n";


                            $formquestion = array_merge($formquestion,
                                array(
                                    array('type' => 'onecolumn', 'name' => 'company_name' . ($v13p ? $more_names : ''), 'value' => $table_choices),
                                )
                            );

                            $langs->load('sirene@sirene');

                            print $form->formconfirm($_SERVER["PHP_SELF"] . '?socid=' . $object->id, $langs->trans('PopUpChangeBoxSirene'), $langs->trans(""), "confirm_sir_data", $formquestion, 'no', 1, 600, '80%');
                    }

                } elseif (empty($object->idprof2) || GETPOST('action') === 'sir_update' ) {
                    //si le SIRET n'est pas renseigné OU action === sir_update (pour mettre à jour un tiers avec un siret fermé)
                    global $conf, $langs, $user, $mysoc;
                    if ($user->rights->societe->creer) {
                        print '<div class="inline-block divButAction"><a class="butAction" href="' . $_SERVER['PHP_SELF'] . '?socid=' . $object->id . '&amp;action=sir_import">' . $langs->trans('SireneButton') . '</a></div>';
                        //Traitement du bouton import tiers
                        $act = GETPOST('action', 'aZ09');

                        if ($act === 'sir_import' || $act === 'sir_update') {
                                //-----------Changement couleur title bar menu-----------------

                                require_once DOL_DOCUMENT_ROOT . '/core/lib/functions2.lib.php';
                                $path = '';        // This value may be used in future for external module to overwrite theme
                                $theme = 'eldy';    // Value of theme
                                if (!empty($conf->global->MAIN_OVERWRITE_THEME_RES)) {
                                    $path = '/' . $conf->global->MAIN_OVERWRITE_THEME_RES;
                                    $theme = $conf->global->MAIN_OVERWRITE_THEME_RES;
                                }

                                include dol_buildpath($path . '/theme/' . $theme . '/theme_vars.inc.php');
                                // Case of option availables only if THEME_ELDY_ENABLE_PERSONALIZED is on
                                $colorbackhmenu1 = empty($user->conf->THEME_ELDY_ENABLE_PERSONALIZED) ? (empty($conf->global->THEME_ELDY_TOPMENU_BACK1) ? $colorbackhmenu1 : $conf->global->THEME_ELDY_TOPMENU_BACK1) : (empty($user->conf->THEME_ELDY_TOPMENU_BACK1) ? $colorbackhmenu1 : $user->conf->THEME_ELDY_TOPMENU_BACK1);

                                // Set text color to black or white
                                $colorbackhmenu1 = join(',', colorStringToArray($colorbackhmenu1));    // Normalize value to 'x,y,z'
                                $tmppart = explode(',', $colorbackhmenu1);
                                $tmpval = (!empty($tmppart[0]) ? $tmppart[0] : 0) + (!empty($tmppart[1]) ? $tmppart[1] : 0) + (!empty($tmppart[2]) ? $tmppart[2] : 0);
                                if ($tmpval <= 460) $colortextbackhmenu = 'FFFFFF';
                                else $colortextbackhmenu = '000000';


                                $langs->load('sirene@sirene');

                                print '<style scoped>
                                    @media only screen and (max-width: 1200px) {
                                        .displaygridonsmartphone {
                                            display: grid;
                                            grid-template-columns: 1fr 1fr;
                                        }
                                        .tablehead{
                                            grid-template-columns: 2fr 1fr;
                                        }

                                        table.liste td, table.noborder td, div.noborder form div, table.tableforservicepart1 td, table.tableforservicepart2 td {
                                            height: unset !important;
                                            border-bottom: unset !important;
                                        }
                                    }
                                    @media only screen and (max-width: 570px) {
                                        .displaygridonsmartphone {
                                            grid-template-columns: 1fr;
                                        }
                                    }

                                    .green {
                                        color: #118822 !important;
                                    }
                                    .warning_text {
                                        font-size:16px;
                                        font-weight:bold
                                    }
                            </style>';

                                $table_choices = '';
                                $table_choices .= '<div id="sirene_block_infos">' . "\n";
                                $table_choices .= '<table class="noborder" width="100%">' . "\n";
                                if (!empty($parameters['closed_thirdparty'])) {
                                    $table_choices .= '<tr style="margin:1em 1em;"><td colspan=4 class="warning_text">'.$langs->trans('PopUpAlertClosedThirdparty').'</td></tr>';
                                }
                                $table_choices .= '<tr class="displaygridonsmartphone">' . "\n";
                                $table_choices .= '<td colspan="3">';
                                $only_open = (isset($_POST['sirene_number']) ? (GETPOST('sirene_only_open', 'int') ? 1 : 0) : 1);
                                $table_choices .= $langs->trans("SireneOnlyOpen") . ' : <input type="checkbox" id="sirene_only_open" name="sirene_only_open" value="1"' . ($only_open ? ('checked="checked"') : '') . '>' . "\n";
                                $table_choices .= '<td colspan="2" class="center"><button class="button" type="button" id="btn_hidden_inputs" >+ de critères</button></td>';
                                $table_choices .= '</td>' . "\n";
                                $table_choices .= '</tr>' . "\n";
                                $table_choices .= '<tr class="displaygridonsmartphone">' . "\n";

                                $sireneExName = "ex. " . (empty($object->name) ? (empty($mysoc->name) ? "Association dolibarr" : $mysoc->name) : $object->name);
                                $table_choices .= '<td><label for="sirene_company_name">' . $langs->trans("SireneCompanyName") . '</label><br><input type="text" id="sirene_company_name" name="sirene_company_name" placeholder="' . $sireneExName . '" value="'.$object->name.'"></td>' . "\n";

                                $sireneExSiren = "ex. " . (empty($object->idprof1) ? (empty($mysoc->idprof1) ? "520339938" : str_replace(' ', '', $mysoc->idprof1)) : str_replace(' ', '', $object->idprof1));
                                $table_choices .= '<td><label for="sirene_siren_siret">' . $langs->trans("SireneSiren") . ' / '.$langs->trans("SireneSiret") . '</label><br><input type="text" id="sirene_siren_siret" name="sirene_siren_siret" placeholder="' . $sireneExSiren . '" value="'.$object->idprof1.'"></td>' . "\n";

                                $sireneExRna = "ex. " . (empty($object->idprof6) ? (empty($mysoc->idprof6) ? "rna" : str_replace(' ', '', $mysoc->idprof6)) : str_replace(' ', '', $object->idprof6));
                                $table_choices .= '<td><label for="sirene_naf">' . $langs->trans("SireneRna") . ' ' . $form->textwithpicto('', $langs->trans("SireneSearchCodeNafHelp"), 2) . '</label><br><input type="text" id="sirene_rna" name="sirene_rna" placeholder="' . $sireneExRna . '" value="'.$object->idprof6.'"></td>' . "\n";

                                $sireneExNaf = "ex. " . (empty($object->idprof3) ? (empty($mysoc->idprof3) ? "94.99Z" : substr($mysoc->idprof3, 0, 2) . '.' . substr($mysoc->idprof3, 2, 3)) : substr($object->idprof3, 0, 2) . '.' . substr($object->idprof3, 2, 3));
                                $table_choices .= '<td><label for="sirene_naf">' . $langs->trans("SireneNaf") . ' ' . $form->textwithpicto('', $langs->trans("SireneSearchCodeNafHelp"), 2) . '</label><br><input type="text" id="sirene_naf" name="sirene_naf" placeholder="' . $sireneExNaf . '" value="'.$object->idprof3.'"></td>' . "\n";

                                $table_choices .= '</tr>' . "\n";
                                $table_choices .= '<tr class="displaygridonsmartphone" id="second_line_inputs_siren" style="display:none">' . "\n";

                                $sireneExTown = "ex. " . (empty($object->town) ? (empty($mysoc->town) ? "Lyon" : $mysoc->town) : $object->town);
                                $table_choices .= '<td colspan="1" class=""><label for="sirene_town_input">' . $langs->trans("SireneTown") . '<br><input type="text" name="sirene_town" id="sirene_town_input" placeholder="' . $sireneExTown . '" value="'.$object->town.'"></td>' . "\n";

                                $sireneExZip = "ex. " . (empty($object->zip) ? (empty($mysoc->zip) ? "45160" : $mysoc->zip) : $object->zip);
                                $table_choices .= '<td colspan="5" class=""><label for="sirene_zipcode_input">' . $langs->trans("CompanyZip") . '<br><input type="text" name="sirene_zipcode" id="sirene_zipcode_input" placeholder="' . $sireneExZip . '" value="'.$object->zip.'"></td>' . "\n";

                                $table_choices .= '</tr>' . "\n";
                                $script_js_to_display_hidden_inputs = dol_buildpath('/sirene/js/display_hidden_inputs.js', 1);

                                $table_choices .=  '<script src="'.$script_js_to_display_hidden_inputs.'"></script>';

                                $table_choices .= '</tr>' . "\n";
                                $table_choices .= '</table>' . "\n";
                                $table_choices .= '</div>' . "\n";
                                $table_choices .= '<div class="center">' . "\n";
                                $table_choices .= '<input type="submit" id="sirene_search" name="sirene_search" class="button" value="' . $langs->trans("Search") . '">' . "\n";
                                $table_choices .= '</div>' . "\n";
                                $table_choices .= '<div id="sirene_search_result"></div>' . "\n";

                                $ajax_url = dol_buildpath('/sirene/ajax/search_result.php', 1);
                                $new_token = newToken();
                                $socid = $object->id > 0 ? $object->id : 0;
                                $waiting_label = $langs->trans("SireneWaitingMessage");
                                $search_label = $langs->trans("Search");
                                $outJS = <<<SCRIPT
                        <script type="text/javascript">
                            jQuery(document).ready(function(){
                                var s_dialog_confirm = $('#dialog-confirm');

                                sirene_search();
                                jQuery("#sirene_search").click(function(){
                                    sirene_search();
                                });

                                s_dialog_confirm.on("dialogopen", function(event, ui) {
                                    var parent = s_dialog_confirm.parent();
                                    parent.find('.ui-dialog-titlebar').addClass('sirene_title');
                                    parent.find('.ui-dialog-buttonset').addClass('sirene_remove');
                                    parent.find('.ui-dialog-buttonpane').addClass('sirene_remove');
                                    parent.find('.border-bottom-color').addClass('sirene_background');
                                    parent.find('.noborder centpercent').addClass('sirene_colortitre');
                                    parent.find('.liste_titre').addClass('sirene_colortitre');
                                });

                                function sirene_search() {
                                    $("input#sirene_search").addClass("butActionRefused").val("$waiting_label");
                                    jQuery("#sirene_search_result").html("");
                                    jQuery.ajax({
                                        method: "post",
                                        dataType: "json",
                                        data: {
                                            token: "$new_token",
                                            socid: "$socid",
                                            sirene_only_open: jQuery("#sirene_only_open").is(":checked") ? 1 : 0,
                                            sirene_company_name: jQuery("#sirene_company_name").val(),
                                            sirene_rna: jQuery("#sirene_rna").val(),

                                            sirene_siren_siret: jQuery("#sirene_siren_siret").val(),
                                            sirene_naf: jQuery("#sirene_naf").val(),
                                            sirene_town: jQuery("#sirene_town_input").val(),
                                            sirene_zipcode: jQuery("#sirene_zipcode_input").val()
                                        },
                                        url: "$ajax_url"
                                    }).fail(function(jqxhr, textStatus, error) {
                                        jQuery("#sirene_search_result").html("Error: " + textStatus + " - " + error);
                                        $("input#sirene_search").removeClass("butActionRefused").val("$search_label");
                                    }).done(function(response) {
                                        jQuery("#sirene_search_result").html(response.html);
                                        $("input#sirene_search").removeClass("butActionRefused").val("$search_label");
                                    })
                                }
                            });
                        </script>

                        <style>
                            .sirene_title {
                                background-color: rgb($colorbackhmenu1) !important;
                                color: #$colortextbackhmenu !important;
                            }
                            .sirene_remove{
                                display: none !important;
                            }
                            .sirene_background{
                                   background-color: white !important;
                            }
                            .sirene_colortitre{
                                background-color: rgb($colorbackhmenu1) !important;
                                color: #$colortextbackhmenu !important;
                            }
                        </style>
SCRIPT;

                                $table_choices .= $outJS;
                                $formquestion = array(
                                    array(
                                        'type'  => 'hidden',
                                        'name'  => 'socid',
                                        'value' => GETPOST('socid', 'int')
                                    ),
                                    array(
                                        'type'  => 'hidden',
                                        'name'  => 'old_action',
                                        'value' => $action
                                    ),
                                    array(
                                        'name'  => 'sirene_choice',
                                        'type'  => 'onecolumn',
                                        'value' => $table_choices
                                    )
                                );
                                print $form->formconfirm($_SERVER["PHP_SELF"], $langs->trans("PopUpSelectionTier"), $langs->trans("PopUpSelectionTierMsg"), "sir_import", $formquestion, '1', 1, 750, '75%');
                                return 0;
                        }
                    }
                }
            }
        }

        return 0;
    }


    /**
     * @param array $company_infos
     * @param bool $checked if the radio input is checked
     * @return string $table_row. A table row with company infos
     */
    private function makeTableRowCompany($company_infos, $checked)
    {
        global $langs;

        $table_row = '';
        $siege_html = '';
        if (!empty($company_infos['siege'])) {
            $siege_html .= '&nbsp;<span class="fa fa-star classfortooltip green" style="font-size: 0.8em;" title="'.$langs->trans('SireneCompanySiegeHelp').'"></span>';
        }

        $table_row .= '<tr class="oddeven">' . "\n";
        $table_row .= '<td><input type="radio" id="sirene_choice" name="sirene_choice" ';

        if ($checked){
            $table_row .= ' checked';
        }

        if ($company_infos['siret']) {
            $table_row .= ' value="' . $company_infos['siret']  . '"></td>' . "\n";
        } elseif ($company_infos['rna']) {
            $table_row .= ' value="' . $company_infos['rna']  . '"></td>' . "\n";
        }

        $company_name = !empty($company_infos['company_name_all']) ? $company_infos['company_name_all'] : $langs->trans('SireneValueUndefined');
        $company_address = !empty($company_infos['address_all']) ? $company_infos['address_all'] : $langs->trans('SireneValueUndefined');
        $company_date_creation = !empty($company_infos['date_creation']) ? $company_infos['date_creation'] : $langs->trans('SireneValueUndefined');

        $table_row .= '<td>' . $company_name  . $siege_html . '</td>' . "\n";
        $table_row .= '<td>' . $company_address . '</td>' . "\n";
        $table_row .= '<td>' . $company_date_creation . '</td>' . "\n";
        $table_row .= '<td>' . $company_infos['status_all'] . '</td>' . "\n";
        $table_row .= '<td>' . $company_infos['codenaf_all'] . '</td>' . "\n";
        $table_row .= '<td>' . $company_infos['siren'] . '</td>' . "\n";
        $table_row .= '<td>' . $company_infos['siret'] . '</td>' . "\n";
        $table_row .= '<td>' . $company_infos['rna'] . '</td>' . "\n";
        $table_row .= '</tr>' . "\n";
        return $table_row;
    }


    /**
     * display the sirene form
     *
     * @return void
     */
    private function display_sirene_form()
    {
        global $conf, $langs, $form, $user, $mysoc;

        $langs->load('sirene@sirene');

        print '<style scoped>
            @media only screen and (max-width: 1200px) {
                .displaygridonsmartphone {
                    display: grid;
                    grid-template-columns: 1fr 1fr;
                }
                .tablehead{
                    grid-template-columns: 2fr 1fr;
                }

                table.liste td, table.noborder td, div.noborder form div, table.tableforservicepart1 td, table.tableforservicepart2 td {
                    height: unset !important;
                    border-bottom: unset !important;
                }
            }
                @media only screen and (max-width: 570px) {
                    .displaygridonsmartphone {
                        grid-template-columns: 1fr;
                    }
                }
                .green {
                    color: #118822 !important;
                }
        </style>';

        print '<tr id="sirene_infos"><td colspan="4">' . "\n";
        print '<div id="sirene_block_infos">' . "\n";
        print '<table class="noborder centpercent tableforfieldcreate table">' . "\n";
        print '<tr class="displaygridonsmartphone tablehead">' . "\n";
        print '<td colspan="6" class="maxwidth400onsmartphone"><u>' . $langs->trans("SireneSirene") . '</u> ' . $form->textwithpicto('', $langs->trans("SireneSearchHelp"), 2) . "\n";

        $only_open = (isset($_POST['sirene_number']) ? (GETPOST('sirene_only_open', 'int') ? 1 : 0) : 1);

        if (isset($_POST['sirene_number'])) {
            if (!empty(GETPOST('sirene_only_open_siege', 'int'))) {
                $only_open_siege = 1;
            } else {
                $only_open_siege = 0;
            }
        } elseif (!empty($conf->global->SIRENE_SIEGE_BY_DEFAULT)) {
            $only_open_siege = 1;
        } else {
            $only_open_siege = 0;
        }


        print '<br>' . $langs->trans("SireneOnlyOpen") . ' : <input type="checkbox" name="sirene_only_open" value="1"' . ($only_open ? ('checked="checked"') : '') . '>&nbsp;&nbsp;&nbsp;' . "\n";
        print $langs->trans("SireneOnlyOpenSiege") . ' : <input type="checkbox" name="sirene_only_open_siege" value="1"' . ($only_open_siege ? ('checked="checked"') : '') . '></br>' . "\n";
        print '<td colspan="6" class="center"><button class="button" type="button" id="btn_hidden_inputs" >+ de critères</button></td>';
        print '</tr>' . "\n";
        print '<tr class="displaygridonsmartphone">' . "\n";

        // first line of inputs

        $sireneExName = empty($mysoc->name) ? "ex. Association dolibarr" : "ex. " . $mysoc->name;
        print '<td class="maxwidth400onsmartphone"><label for="sirene_name_input">' . $langs->trans("SireneCompanyName") . '</label><br><input type="text" class="" name="sirene_company_name" id="sirene_name_input" placeholder="' . $sireneExName . '" value="' . GETPOST('sirene_company_name', 'alpha') . '"></td>' . "\n";

        $siren_siret = GETPOST('siren_siret', 'alpha');
        $siren_siret = str_replace(' ', '', $siren_siret);

        $sireneExSiren = empty($mysoc->idprof1) ? "ex. 520339938" : "ex. " . str_replace(' ', '', $mysoc->idprof1);
        print '<td class="maxwidth400onsmartphone"><label for="sirene_siren_siret">' . $langs->trans("SireneSiren") . ' / '.$langs->trans("SireneSiret") . '</label><br><input type="text" name="siren_siret" id="siren_siret_input" placeholder="' . $sireneExSiren . '" value="' . $siren_siret . '"></td>' . "\n";

        $sirene_naf = GETPOST('sirene_naf', 'alpha');

        if (!empty($sirene_naf) && stristr($sirene_naf, '.') === false ) {
            $sirene_naf = substr($sirene_naf, 0, 2) . '.' . substr($sirene_naf, 2, 3);
        }

        $sirene_naf = str_replace(' ', '', $sirene_naf);

        $sireneExNaf = empty($mysoc->idprof3) ? "ex. 94.99Z" : "ex. " . substr($mysoc->idprof3, 0, 2) . '.' . substr($mysoc->idprof3, 2, 3);
        print '<td class="maxwidth400onsmartphone"><label for="sirene_naf_input">' . $langs->trans("SireneNaf") . ' ' . $form->textwithpicto('', $langs->trans("SireneSearchCodeNafHelp"), 2) . '<br><input type="text" name="sirene_naf" id="sirene_naf_input" placeholder="' . $sireneExNaf . '" value="' . $sirene_naf . '"></td>' . "\n";

        $sirene_rna = GETPOST('sirene_rna', 'alpha');
        $sirene_rna = str_replace(' ', '', $sirene_rna);

        $sireneExRna = empty($mysoc->idprof6) ? "ex. rna" : "ex. " . str_replace(' ', '', $mysoc->idprof6);
        print '<td class="maxwidth400onsmartphone"><label for="sirene_rna_input">' . $langs->trans("SireneRna") . '</label><br><input type="text" name="sirene_rna" id="sirene_rna_input" placeholder="' . $sireneExRna . '" value="' . $sirene_rna . '"></td>' . "\n";
        print '</tr>' . "\n";
        print '<tr class="displaygridonsmartphone" id="second_line_inputs_siren" style="display:none">' . "\n";

        // hiden second line of inputs

        $sireneExTown = empty($mysoc->town) ? "ex. Lyon" : "ex. " . $mysoc->town;
        print '<td class="maxwidth400onsmartphone"><label for="sirene_town_input">' . $langs->trans("SireneTown") . '<br><input type="text" name="sirene_town" id="sirene_town_input" placeholder="'.$sireneExTown.'" value="' .  GETPOST('sirene_town', 'alpha')  . '"></td>' . "\n";

        $sireneExZip = empty($mysoc->zip) ? "ex. 45160" : "ex. " . $mysoc->zip;
        print '<td class="maxwidth400onsmartphone"><label for="sirene_zipcode_input">' . $langs->trans("CompanyZip") . '<br><input type="text" name="sirene_zipcode" id="sirene_zipcode_input" placeholder="' . $sireneExZip . '" value="' . GETPOST('sirene_zipcode', 'alpha') . '"></td>' . "\n";
        print '<td class="maxwidth400onsmartphone"><label for="sirene_qty_input">' . $langs->trans("SireneNumber") . '<br><input type="number" name="sirene_number" id="sirene_qty_input" placeholder="20" min="20" max="100" size="3" value="' . GETPOST('sirene_number', 'alpha') . '"></td>' . "\n";

        print '</tr>' . "\n";

        print '</tr>' . "\n";
        print '<tr>' . "\n";
        print '<td colspan="7" class="center"><input type="submit" id="sirene_search_btn" name="sirene_search" class="button" value="' . $langs->trans("Search") . '"></td>' . "\n";
        print '</tr>' . "\n";
        print '</table>' . "\n";

        $script_js_to_display_hidden_inputs = dol_buildpath('/sirene/js/display_hidden_inputs.js', 1);
        print '<script src="'.$script_js_to_display_hidden_inputs.'"></script>';
    }


    /**
     * @return array of correspondances between company_infos results from Sirene or RNA api
     * and Societe object
     */
    private function getCorrespondanceArrayBetweenCompanyInfoAndSocieteObj()
    {
        return array(
            'company_name'          => 'name',
            'company_name_alias'    => 'name_alias',
            'address'               => 'address',
            'zipcode'               => 'zip',
            'town'                  => 'town',
            'state_id'              => 'state_id',
            'siren'                 => 'idprof1',
            'siret'                 => 'idprof2',
            'codenaf_san'           => 'idprof3',
            'rna'                   => 'idprof6',
            'sirene_tva_intra'      => 'tva_intra',
            'country'               => 'country',
            'country_id'            => 'country_id',
            'country_code'          => 'country_code',
            'country_san'           => 'country_san',
            'staff'                 => 'effectif_id',
            'legalcategory'         => 'forme_juridique_code'
        );
    }


    /** calculate vat intracommunity number from siren number
     *
     * @param int $siren the siren number
     */
    private function calculateIntraCommunityVat(int $siren): int
    {
        return 12 + 3 * ($siren % 97) % 97;
    }

    /**
     * @param bool $modified
     * @param CommonObject $object The object to update
     * @param $user User that updates the object
     * @return -1 on error, 0 on success
     */
    private function updateObjectFields($modified, $object, $user)
    {
        if ($modified) {
            if ($object->update($object->id, $user) < 0) {
                setEventMessages($object->error, $object->errors, 'errors');
                return -1;
            }
        } else {
            if ($object->updateExtraField('sirene_status') < 0) {
                setEventMessages($object->error, $object->errors, 'errors');
                return -1;
            }
            if ($object->updateExtraField('sirene_update_date') < 0) {
                setEventMessages($object->error, $object->errors, 'errors');
                return -1;
            }
            if ($object->updateExtraField('sirene_company_admin_status') < 0) {
                setEventMessages($object->error, $object->errors, 'errors');
                return -1;
            }
        }
        return 0;
    }
}
